<?php
/*
 * This file is part of the MagmaCore package.
 *
 * (c) Ricardo Miller <ricardomiller@lava-studio.co.uk>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
declare(strict_types=1);

namespace MagmaCore\Widget\Widgets\Cards;

use MagmaCore\Widget\Widget;
use MagmaCore\Widget\Widgets\BaseWidget;
use MagmaCore\Widget\Widgets\WidgetBuilderInterface;
use MagmaCore\DataObjectLayer\ClientRepository\ClientRepositoryInterface;

class TotalVisitWidget extends Widget implements WidgetBuilderInterface
{   

    /* @var string the widget name */
    public const WIDGET_NAME = 'total_visit_widget';
    private const LABEL = 'Visitor Sessions';


    /**
     * @inheritDoc
     */
    public static function render(?string $widgetName = null, ClientRepositoryInterface $clientRepo, BaseWidget $baseWidget, mixed $widgetData = null): string
    {
        if ($widgetName === self::WIDGET_NAME) {
            return $baseWidget::card(function($base) {
                return sprintf(
                    '      
                    <div class="uk-clearfix">
                        <div class="uk-float-left">
                            <h3 class="uk-card-title uk-text-bolder uk-margin-remove">%s</h3>
                            <span class="uk-margin-remove uk-text-meta">%s</span>
                            <span class="uk-text-small">
                                %s
                                <span class="uk-text-success uk-margin-left">
                                    %s <span uk-icon="icon: triangle-%s"></span>
                            </span>
                            </span>
        
                        </div>
                        <div class="uk-float-right">
                            <div id="visitor_sessions"></div>
                        </div>
                    </div>
                    %s
                    ',
                    self::LABEL,
                    'Total visits today',
                    '1.4k',
                    '15.9%',
                    'up',
                    self::script()
                );
            },
            'default'
            );
        }        
    }

    /**
     * Returns the sparklines graph for this card
     *
     * @param object $clientRepo
     * @return string
     */
    private static function script(): string
    {
        $output = '
        <script>
        $("#visitor_sessions").sparkline([1432, 874, 972, 643], {
            type: "bar",
            height: "60",
            barWidth: "10",
            barColor: "#FF4444"
        });
    
        </script>
        ';

        return $output;
    }


}
